from edc_consent.managers import ConsentObjectsByCdefManager, CurrentSiteByCdefManager
from edc_model.models import HistoricalRecords

from meta_consent.models import SubjectConsent


class SubjectConsentV1(SubjectConsent):

    objects = ConsentObjectsByCdefManager()

    on_site = CurrentSiteByCdefManager()

    history = HistoricalRecords()

    class Meta:
        proxy = True
        verbose_name = "Consent V1"
        verbose_name_plural = "Consent V1"



# for reference by old migrations
from edc_lab.managers import RequisitionManager as Manager  # noqa
from edc_lab.model_mixins import RequisitionModelMixin
from edc_model.models import BaseUuidModel


class SubjectRequisition(RequisitionModelMixin, BaseUuidModel):
    class Meta(RequisitionModelMixin.Meta, BaseUuidModel.Meta):
        pass
